import unicodedata
from flask import Flask, jsonify, send_file, request
import os
from mutagen.easyid3 import EasyID3

app = Flask(__name__)


def strip_accents(s):
    return ''.join(c for c in unicodedata.normalize('NFD', s)
                   if unicodedata.category(c) != 'Mn')


@app.before_request
def _before_request():
    password = ""
    with open("password.txt", "r") as f:
        password = f.read().strip()
    if password != request.args.get("password"):
        return "Unauthorized", 401


@app.route('/musicdown/reload', strict_slashes=False)
def musicdown_reload():
    music = []

    for file in os.listdir("music"):
        audio = EasyID3("music/" + file)

        music.append({"title": audio["title"][0], "artist": audio["artist"][0], "path": file})

    music.sort(key=lambda x: strip_accents(x["title"].casefold()))

    json = jsonify(music)

    with open("music.json", "w") as f:
        f.write(json.get_data(as_text=True))

    return "ok"


@app.route('/musicdown', strict_slashes=False)
def musicdown_json():
    if os.path.exists("music.json"):
        return send_file("music.json", mimetype="application/json")
    else:
        return "[]"


@app.route('/musicdown/<file>', strict_slashes=False)
def musicdown_file(file=None):
    if "/" in file:
        return "File not found", 404
    if os.path.isfile("music/" + file):
        return send_file("music/" + file, as_attachment=True)
    else:
        return "File not found", 404


if __name__ == "__main__":
    port = 25250
    app.run(debug=False, host='0.0.0.0', port=port)
